summaryrefslogtreecommitdiff
path: root/extensions/dict_legacy_xml/dict_lxml_xml.c
diff options
context:
space:
mode:
Diffstat (limited to 'extensions/dict_legacy_xml/dict_lxml_xml.c')
-rw-r--r--extensions/dict_legacy_xml/dict_lxml_xml.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/extensions/dict_legacy_xml/dict_lxml_xml.c b/extensions/dict_legacy_xml/dict_lxml_xml.c
index eab8cde..3aa3807 100644
--- a/extensions/dict_legacy_xml/dict_lxml_xml.c
+++ b/extensions/dict_legacy_xml/dict_lxml_xml.c
@@ -2,7 +2,7 @@
* Software License Agreement (BSD License) *
* Author: Sebastien Decugis <sdecugis@freediameter.net> *
* *
-* Copyright (c) 2013, WIDE Project and NICT *
+* Copyright (c) 2017, WIDE Project and NICT *
* All rights reserved. *
* *
* Redistribution and use of this software in source and binary forms, with or without modification, are *
@@ -1313,7 +1313,7 @@ static int resolve_base_type(struct dictionary * fD_dict, uint8_t * type_name, e
PREDEF_TYPES( "Integer32", AVP_TYPE_INTEGER32 );
PREDEF_TYPES( "Integer64", AVP_TYPE_INTEGER64 );
PREDEF_TYPES( "Unsigned32", AVP_TYPE_UNSIGNED32 );
- PREDEF_TYPES( "Enumerated", AVP_TYPE_UNSIGNED32 );
+ PREDEF_TYPES( "Enumerated", AVP_TYPE_INTEGER32 );
PREDEF_TYPES( "Unsigned64", AVP_TYPE_UNSIGNED64 );
PREDEF_TYPES( "Float32", AVP_TYPE_FLOAT32 );
PREDEF_TYPES( "Float64", AVP_TYPE_FLOAT64 );
@@ -1453,8 +1453,8 @@ static int avp_to_fD(struct t_avp * a, struct dictionary * fD_dict, struct dict_
/* special exception: we use per-AVP enumerated types in fD */
if (!strcasecmp("Enumerated", (char *)((struct t_avptype *)a->type.next)->type_name))
goto enumerated;
- /* Let's allow "Unsigned32" instead of "Enumerated" also... */
- if ((!FD_IS_LIST_EMPTY(&a->enums)) && (!strcasecmp("Unsigned32", (char *)((struct t_avptype *)a->type.next)->type_name)))
+ /* Let's allow "Integer32" instead of "Enumerated" also... */
+ if ((!FD_IS_LIST_EMPTY(&a->enums)) && (!strcasecmp("Integer32", (char *)((struct t_avptype *)a->type.next)->type_name)))
goto enumerated;
/* The type was explicitly specified, resolve it */
@@ -1479,15 +1479,15 @@ static int avp_to_fD(struct t_avp * a, struct dictionary * fD_dict, struct dict_
struct dict_type_data tdata;
enumerated:
- snprintf(typename, sizeof(typename), "Enumerated*(%s)", ad.avp_name);
+ snprintf(typename, sizeof(typename), "Enumerated(%s)", ad.avp_name);
memset(&tdata, 0, sizeof(tdata));
- tdata.type_base = AVP_TYPE_UNSIGNED32;
+ tdata.type_base = AVP_TYPE_INTEGER32;
tdata.type_name = &typename[0];
CHECK_FCT( fd_dict_new ( fD_dict, DICT_TYPE, &tdata, fd_appl, &type ) );
if (nb_added)
*nb_added += 1;
- ad.avp_basetype = AVP_TYPE_UNSIGNED32;
+ ad.avp_basetype = AVP_TYPE_INTEGER32;
}
}
}